Monty Python's Flying Circus: Just the Words - Episode 16

# Episode Sixteen

A bishop rehearsing
Flying lessons
Hijacked plane (to Luton)
The Poet McTeagle
Psychiatrist milkman
Complaints
Déjà vu

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Wide shot of enormous high block of flats. The camera seems to be searching. Suddenly it zooms in on one window. It is a bedroom...a busty girl is looking out the window. She stretches langourously and mouths.
Girl | (dubbed on very badly) My, isn't it hot in here.
| She starts to undress. She gets down to bra and panties, unhitches her bra and is about to slip it off her shoulders exposing her heavy bosoms when...the announcer rises up in front of the window on window cleaner's hoist.
Announcer | And now for something completely different.
| Cut to an orchard or a woodland clearing, in which are a group of stuffed animals; a lion, a tiger, a cow, an elk, a leopard, two small ferrets and an owl on an overhanging branch. Sound of birdsong. The elk explodes. Cut back to John still in front of the window. We can just see Carol behind him in the bedroom casting her panties to one side - that is we just see her arm.
Announcer | And now for something more completely different...
| Cut to 'It's' man
It's Man | It's...
| Animated titles. Cut back to the same group of animals minus the elk. Birdsong etc. The elk's remains are smouldering. The owl explodes, Pan away from the woodland clearing to an open field in which at a distance a bishop in full mitre and robes is pacing up and down holding a script. Mr Chigger in a suit approaches the bishop and we zoom in to hear their conversation.
Bishop | 'Oh Mr Belpit your legs are so swollen' ... swollen .. 'Oh Mr Belpit - oh Mr Belpit your legs are so swollen'. (tries a different voice) 'Oh Mr Belpit., .'
Mr Chigger | Excuse me, excuse me. I saw your advertisement for flying lessons and I'd like to make an application.
Bishop | Nothing to do with me. I'm not in this show.
Mr Chigger | Oh I see. D'you ... d'you., . do you know about the flying lessons?
Bishop | Nothing to do with me. I'm not in this show. This is show five - I'm not in until show eight.
Mr Chigger | Oh I see.
Bishop | I'm just learning my lines, you know. 'Oh Mr Belpit, your legs...'
Mr Chigger | Bit awkward, I'm a bit stuck.
Bishop | Yes, well. Try over there.
| Bishop points to a secretary some yards away sitting at a desk typing. She wears glasses and is very typically a secretary.
Mr Chigger | Oh yes, thanks. Thanks a lot.
Bishop | 'Oh Mr Belpit' - not at all - 'your legs are so swollen'. (He continues rehearsing as Mr Chigger moves over to the secretary)
Mr Chigger | Excuse me, I saw your advertisement for flying lessons and I'd like to make an application.
Secretary | Appointment?
Mr Chigger | Yes, yes.
Secretary | Certainly. Would you come this way, please.
| She gets up, clutching a file and trips off in a typical efficient secretary's walk. Mr Chigger follows. Cut to a river. She goes straight in without looking to right or left, as if she does this routine as a matter of course. Mr Chigger follows. Halfway across the river they pass a couple of business executives hurrying in the opposite direction.
Secretary | Morning, Mr Jones, Mr Barnes.
| Cut to a forest. They come past towards camera, passing a tea trolley on the way with a tea lady and a couple of men around it.
Secretary | Morning Mrs Wills.
Mrs Wills | Morning, luv.
| Arty shot. Skyline of a short sharp hill, as in Bergman's 'Seventh Seal'. They come in frame right and up and over, passing two men and exchanging 'Good mornings'. Cut to seashore. Tripping along, they pass another executive.
Executive | Take this to Marketing, would you.
| They disappear into a cave. We hear footsteps and a heavy door opening.
Secretary's Voice | Just follow me.
Mr Chigger's Voice | Oh thank you.
| Cut to a shopping street. Camera pans in close-up across road surface.
Secretary's Voice | Oh, be careful.
Mr Chigger's Voice | Yes, nearly tripped.
Secretary's Voice | Be there soon.
Mr Chigger's Voice | Good. It's a long way, isn't it?
Secretary's Voice | Oh, get hold of that - watch it.
Voice | Morning.
Secretary's Voice | Morning. Upstairs. Be careful, it's very steep. Almost there.
| Camera reaches a GPO tent in middle of road.
Voice | Morning.
Secretary | Morning. (they emerge from the tent) Will you come this way, please. (cut to interior office, another identical secretary at the desk) In here, please.
Mr Chigger | Thank you. (he enters and first secretary trips off he approaches the second secretary) Hello, I saw your advertisement for flying lessons and I'd like to make an appointment.
Second Secretary | Well, Mr Anemone's on the phone at the moment, but I'm sure he won't mind if you go on in. Through here.
Mr Chigger | Thank you.
| He goes through door. Mr Anemone is suspended by a wire about nine feet off the ground. He is on the telephone.
Mr Anemone | Ah, won't be a moment. Make yourself at home. (into phone) No, no, well look, you can ask Mr Maudling but I'm sure he'll never agree. Not for fifty shillings ... no... no. Bye-bye Gordon. Bye-bye. Oh dear. Bye-bye. (he throws receiver at telephone but misses) Missed. Now Mr er...
Mr Chigger | Chigger.
Mr Anemone | Mr Chigger. So, you want to learn to fly?
Mr Chigger | Yes.
Mr Anemone | Right, well, up on the table, arms out, fingers together, knees bent...
Mr Chigger | No, no, no.
Mr Anemone | (very loudly) Up on the table! (Mr Chigger gets on the table) Arms out, fingers together, knees bent, now, head well forward. Now, flap your arms. Go on, flap, faster... faster... faster... faster, faster, faster, faster - now jump! (Mr Chigger jumps and lands on the floor) Rotten. Rotten. You're no bloody use at all. You're an utter bloody wash-out. You make me sick, you weed!
Mr Chigger | Now look here...
Mr Anemone | All right, all right. I'll give you one more chance, get on the table...
Mr Chigger | Look, I came here to learn how to fly an aeroplane.
Mr Anemone | A what?
Mr Chigger | I came here to learn how to fly an aeroplane.
Mr Anemone | (sarcasticaly) Oh, 'an aeroplane'. Oh, I say, we are grand, aren't we? (imitation posh accent) 'Oh, oh, no more buttered scones for me, mater. I'm off to play the grand piano'. 'Pardon me while I fly my aeroplane.' Now get on the table!
Mr Chigger | Look. No one in the history of the world has ever been able to fly like that.
Mr Anemone | Oh, I suppose mater told you that while you were out riding. Well, if people can't fly what am I doing up here?
Mr Chigger | You're on a wire.
Mr Anemone | Oh, a wire. I'm on a wire, am I?
Mr Chigger | Of course you're on a bloody wire.
Mr Anemone | I am not on a wire. I am flying.
Mr Chigger | You're on a wire.
Mr Anemone | I am flying.
Mr Chigger | You're on a wire.
Mr Anemone | I'll show you whether I'm on a wire or not. Give me the 'oop.
Mr Chigger | What?
Mr Anemone | Oh, I don't suppose we know what an 'oop is. I suppose pater thought they were a bit common, except on the bleedin' croquet lawn.
Mr Chigger | Oh, a hoop.
Mr Anemone | 'Oh an hoop.' (taking hoop) Thank you, your bleeding Highness. Now. Look. (he waves hoop over head and feet)
Mr Chigger | Go on, right the way along.
Mr Anemone | All right, all right, all right. (he moves hoop all the way along himself allowing the wire to pass through obvious gap in hoop's circumference). Now, where's the bleeding wire, then?
Mr Chigger | That hoop's got a hole in.
Mr Anemone | Oh Eton and Madgalene. The hoop has an hole in. Of course it's got a hole in, it wouldn't be a hoop otherwise, would it, mush!
Mr Chigger | No, there's a gap in the middle, there.
Mr Anemone | Oh, a gahp. A gahp in one's hhhhhoop. Pardon me, but I'm off to play the grand piano.
Mr Chigger | Look, I can see you're on a wire - look, there it is.
Mr Anemone | Look, I told you, you bastard, I'm not on a wire.
Mr Chigger | You are. There is.
Mr Anemone | There isn't.
Mr Chigger | Is.
Mr Anemone | Isn't!
Mr Chigger | Is!
Mr Anemone | Isn't!
Mr Chigger | Is!
Mr Anemone | Isn't!
Mr Chigger | Is!
Mr Anemone | Isn't!!
Mr Chigger | Is!!!
Voice Over | Anyway, this rather pointless bickering went on for some time until...
| CAPTION: 'TWO YEARS LATER' Interior cockpit of airliner. Mr Chigger (pilot) and a second pilot sitting at controls.
Mr Chigger | Gosh, I am glad I'm a fully qualified arline pilot.
| Cut to BALPA spokesman sitting at a desk. He is in Captain's uniform and has a name plate in front of him on the desk saying 'BALPA Spokesman'.
BALPA Man | The British Airline Pilots Association would like to point out that it takes a chap six years to become a fully qualified airline pilot, and not two.
| CAPTION: 'FOUR YEARS LATER THAN THE LAST CAPTION' Interior cockpit. For three seconds. Then cut back to BALPA spokesman.
BALPA Man | Thank you. I didn't want to seem a bit of an old fusspot just now you know, but it's just as easy to get these things right as they are easily found in the BALPA handbook. Oh, one other thing, in the Sherlock Holmes last week Tommy Cooper told a joke about a charter flight, omitting to point out that one must be a member of any organization that charters a plane for at least six months beforehand, before being able to take advantage of it. Did rather spoil the joke for me, I'm afraid. (phone ring) Yes, ah yes - yes. (puts phone down) My wife just reminded me that on a recent 'High Chapparal' Kathy Kirby was singing glibly about 'Fly me to the Stars' when of course there are no scheduled flights of this kind, or even chartered, available to the general public at the present moment, although of course, when they are BALPA will be in the vanguard. Or the Trident. Little joke for the chaps up at BALPA House. And one other small point. Why is it that these new lurex dancing tights go baggy at the knees after only a couple of evenings' fun? Bring back the old canvas ones I say. It is incredible, isn't it, that in these days when man can walk on the moon and work out the most complicated hire purchase agreements, I still get these terrible headaches. Well . .. I seem to have wandered a bit, but still, no harm done. Jolly good luck.
| Back in the cockpit of the airliner. The two pilots sit there. Atmospheric noise of a big airliner in flight. Suddenly there is a banging on the door at the back of the cockpit.
Zanie | (off-screen) Are you going to be in there all day? (the two pilots exchange a puzzled look, then shrug and go back to flying; suddenly another series of bangs on door) Other people want to go you know! (they exchange another look; pause; a heavier bang on the door) The door's jammed, if you ask me. (a crash as he attempts to force it; another crash and the door flies open; Mr Zanie enters) Ah. (suddenly realizing where he is) Oh my God. Oh, I'm terribly sorry. I thought this was the bally toilet.
Second Pilot | This is the control cabin.
Zanie | Oh I know that. I'm a flying man, you know... oh yes... Bally stupid mistake...
| A pause. Zanie remains standing at the back of cockpit. The pilots go on as if he is not there.
Second Pilot | Cloud's heavy ... What's the reading?
Mr Chigger | 4.8... Steady.
Zanie | If they had all those dials in the toilet... there wouldn't be room for anything else, would there. (another nervous laugh; not the slightest reaction from the pilots)
Mr Chigger | (into intercom) Hello, Geneva this is Roger Five-O ... What is your cloud reading? Hello, Geneva...
Zanie | I wouldn't fancy flying one of those sitting on the toilet... I mean it'd take the glamour out of being a pilot, wouldn't it, ha ha, flying around the world sitting on a toilet.
Radio Voice | Geneva here. 4.9 ... Heavy... Over.
Mr Chigger | Serious?
Second Pilot | No, not if it keeps at that level, no.
Zanie | Mind you, if you did fly it from the toilet it would leave a lot more space up here, wouldn't it. (finally he realizes his attempt at small talk is not working) Well, I'd better get back to the cabin, then. Sorry about the silly intrusion. Bally stupid. (he pushes lever down on the door which opens directly out of the plane) Door's jammed. (he gives it a shoulder charge and flies straight out of the plane) Aaaaaaaaaarrrggghhhhhh!
| Plane noise overhead. Continue scream. Outside of a gent's lavatory, there is a big pile of straw. Pause, then Zanie drops onto the straw. He looks up at gent's sign.
Zanie | Bally piece of luck...
| He brushes himself down and goes into gents. Cut back to cockpit. A hostess enters from the passenger cabin.
Second Pilot | Oh hello. Everything all right at the back?
Hostess | Yes, they're as quiet as dormice.
Second Pilot | Dormice?
| Door opens and a man in a neat suit enters. From beneath his jacket he produces a revolver with silencer attachment. He points it at the pilots.
Gunman | All right, don't anybody move ... except to control the aeroplane ... you can move a little to do that.
Hostess | Can I move?
Gunman | Yes, yes, yes. You can move a little bit. Yes. Sorry, I didn't mean to be so dogmatic when I came in. Obviously you can all move a little within reason. There are certain involuntary muscular movements which no amount of self-control can prevent. And obviously any assertion of authority on my part, I've got to take that into account.
| The ensuing conversation is perfectly calm and friendly.
Second Pilot | Right. I mean one couldn't for example, stop one's insides from moving.
Gunman | No, no. Good point, good point.
Second Pilot | And the very fact that the plane is continuously vibrating means that we're all moving to a certain extent.
Gunman | And we're all moving our lips, aren't we?
Pilots | Yes, yes.
Second Pilot | Absolutely.
Gunman | No, the gist of my meaning was that sudden... er...
Hostess | Exaggerated movements ...
Gunman | Exaggerated violent movements... are... are out.
Second Pilot | Well, that's the great thing about these modern airliners. I mean, I can keep this plane flying with only the smallest movement and Pancho here doesn't have to move at all.
Gunman | Oh, that's marvellous.
Hostess | (joining in the general spirit of bonhomie) And I don't really need to move either ... unless I get an itch or something...
| They all laugh.
Gunman | Well that's wonderful ... 60% success, eh? (they laugh again) Anyway, bearing all that in mind, will you fly this plane to Luton, please?
Second Pilot | Well, this is a scheduled flight to Cuba.
Gunman | I know, I know, that's rather why I came in here with that point about nobody moving.
First Pilot | Within reason.
Gunman | Within reason - yes. I... er ... er... you know, I want you to fly this plane to Luton ... please.
Second Pilot | Right, well I'd better turn the plane round then. Stand by emergency systems.
Gunman | Look I don't want to cause any trouble.,
Second Pilot | No, no, we'll manage, we'll manage.
Gunman | I mean, near Luton will do, you know. Harpenden, do you go near Harpenden?
First Pilot | It's on the flight path.
Gunman | Okay, well, drop me off there. I'll get a bus to Luton. It's only twenty-five minutes.
Hostess | You can be in Luton by lunchtime.
Gunman | Oh, well that's smashing.
First Pilot | Hang on! There's no airport at Harpenden.
Gunman | Oh well, look, forget it. Forget it. I'll come to Cuba, and get a flight back to Luton from there.
Second Pilot | Well, we could lend you a parachute.
Gunman | No, no, no, no, no. I wouldn't dream of it... wouldn't dream of it... dirtying a nice, clean parachute.
First Pilot | I know - I know. There's a bale of hay outside Basingstoke. We could throw you out.
Gunman | Well, if it's all right.
All | Sure, yeah.
Gunman | Not any trouble?
Pilots | None at all.
Gunman | That's marvellous. Thank you very much. Sorry to come barging in.
Hostess | Bye-bye.
Gunman | Thank you. Bye.
Pilots | Bye.
| They open the door and throw him out.
Gunman | (as he falls) Thank you!
| Cut to haystack in a field (not the same bale of hay that was landed on before). Aeroplane noise overhead. The gunman suddenly falls into the haystack. He gets up, brushes himself down, hops over a fence, and reaches a road. He puts his hand out and a bus stops. It has 'Straight to Luton' written on it. He gets in. Conductor is just about to take his fare, when an evil-looking man with a gun jumps up and points gun at conductor.
Hijacker | Take this bus to Cuba.
| Bus moving away from camera. The destination board changes to 'Straight to Cuba'. The bus does a speedy u-turn, and goes out of frame. Camera pans away revealing a rather rocky highland landscape. As camera pans across country we hear inspiring Scottish music.
Voice Over | From these glens and scars, the sound of the coot and the moorhen is seldom absent. Nature sits in stern mastery over these rocks and crags. The rush of the mountain stream, the bleat of the sheep, and the broad, clear Highland skies, reflected in turn and loch ... (at this moment we pick up a highland gentleman in kilt and tam o'shanter clutching a knobkerry in one hand and a letter in the other)... form the breathtaking backdrop against which Ewan McTeagle writes such poems as 'Lend us a quid till the end of the week'.
| Cut to crofter's cottage. McTeagle sits at the window writing. We zoom in very slowly on him us he writes.
Voice Over | But it was with more simple, homespun verses that McTeagle's unique style first flowered.
McTeagle | (voice over) If you could see your way to lending me sixpence. I could at least buy a newspaper. That's not much to ask anyone.
Voice Over | One woman who remembers McTeagle as a young friend - Lassie O'Shen.
| Cut to Lassie O'Shen - a young sweet innocent Scots girl - she is valiantly trying to fend off the sexual advances of the sound man. Two other members of the crew pull him out of shot.
Lassie | Mr MeTeagle wrote me two poems, between the months of January and April 1969...
Interviewer | Could you read us one?
Lassie | Och, I dinna like to... they were kinda personal... but I will. (she has immediately a piece of paper in her hand from which she reads) 'To Ma Own beloved Lassie. A poem on her 17th Birthday. Lend us a couple of bob till Thursday. I'm absolutely skint. But I'm expecting a postal order and I can pay you back as soon as it comes. Love Ewan.'
| There is a pause. She looks up.
Sound Man | (voice over) Beautiful.
| Another pause. The soundman leaps on her and pulls her to the ground. Cut to abstract trendy arts poetry programme set. Intense critic sits on enormous inflatable see-through pouffe. CAPTION: 'ST JOHN LIMBO -- POETRY EXPERT'
Limbo | (intensely) Since then, McTeagle has developed and widened his literary scope. Three years ago he concerned himself with quite small sums - quick bits of ready cash: sixpences, shillings, but more recently he has turned his extraordinary literary perception to much larger sums - fifteen shillings, £4.12.6 ... even nine guineas ... But there is still nothing to match the huge sweep ... the majestic power of what is surely his greatest work: 'Can I have fifty pounds to mend the shed?'.
| Pan across studio to a stark poetry-reading set. A single light falls on an Ian McKellan figure in black leotard standing gazing dramatically into space. Camera crabs across studio until it is right underneath him. He speaks the lines with great intensity.
Ian | Can I have fifty pounds to mend the shed? I'm right on my uppers. I can pay you back When this postal order comes from Australia. Honestly. Hope the bladder trouble's getting better. Love, Ewan.
| Cut to remote Scottish landscape, craggy and windtorn and desolate. In stark chiaroscuro against the sky we see McTeagle standing beside a lonely pillar box, writing postcards. The sun setting behind him.
Limbo | (voice over) There seems to be no end to McTeagle's poetic invention. 'My new cheque book hasn't arrived' was followed up by the brilliantly allegorical 'What's twenty quid to the bloody Midland Bank?' and more recently his prizewinning poem to the Arts Council: 'Can you lend me one thousand quid?'
| Cut to David Mercer figure in his study at a desk. CAPTION: 'A VERY GOOD PLAYWRIGHT'
David | I think what McTeagle's pottery... er... poetry is doing is rejecting all the traditional cliches of modern pottery. No longer do we have to be content with Keats's 'Seasons of mists and mellow fruitfulness', Wordsworth's 'I wandered lonely as a cloud' and Milton's 'Can you lend us two bob till Tuesday'...
| Cut to long shot of McTeagle walking through countryside.
McTeagle | (voice over) Oh give to me a shillin' for some fags and I'll pay yet back on Thursday, but if you can wait till Saturday I'm expecting a divvy from the Harpenden Building Society... (continues muttering indistinctly)
| He walks out of shot past a glen containing several stuffed animals, one of which explodes. A highland spokesman stands up into shot. SUERIMPOSED CAPTION: 'A HIGHLAND SPOKESMAN'
Highlander | As a Highlander I would like to complain about some inaccuracies in the preceding film about the poet Ewan McTeagle. Although his name was quite clearly given as McTeagle, he was throughout wearing the Cameron tartan. Also I would like to point out that the BALPA spokesman who complained about aeronautical inaccuracies was himself wearing a captain's hat, whereas he only had lieutenant's stripes on the sleeves of his jacket. Also, in the Inverness pantomime last Christmas, the part of Puss in Boots was played by a native of New Guinea with a plate in her lip, so that every time Dick Whittington gave her a French kiss, he got the back of his throat scraped.
| A doctor's head appears out from under the kilt.
Doctor | Look, would you mind going away, I'm trying to examine this man. (he goes back under the kilt; a slight pause; he re-emerges) It's - er - it's all right - I am a doctor. Actually, I'm a gynaecologist... but this is my lunchhour.
| ANIMATION:
Animation Voice | I've a nasty feeling I am somebody's lunchhour.
| Animation leads to a living room. Doorbell rings. Lady opens the door, a milkman stands there.
Milkman | Pat-a-cake, pat-a-cake baker's man. Good morning, madam, I'm a psychiatrist.
Lady | You look like a milkman to me.
Milkman | Good. (ticks form on his clipboard) I am in fact dressed as a milkman... you spotted that - well done.
Lady | Go away.
Milkman | Now then, madam. I'm going to show you three numbers, and I want you to tell me if you see any similarity between them. (holds up a card saying '3' three times)
Lady | They're all number three.
Milkman | No. Try again.
Lady | They're all number three?
Milkman | No. They're all number three. (he ticks his board again) Right. Now. I'm going to say a word, and I want you to say the first thing that comes into your head. How many pints do you want?
Lady | (narrowing her eyes, suspecting a trap) Er, three?
Milkman | Yogurt?
Lady | Er... no.
Milkman | Cream?
Lady | No.
Milkman | Eggs?
Lady | No.
Milkman | (does some adding up and whistling) Right. Well, you're quite clearly suffering from a repressive libido complex, probably the product of an unhappy childhood, coupled with acute insecurity in adolescence, which has resulted in an attenuation of the libido complex.
Lady | You are a bloody milkman.
Milkman | Don't you shout at me, madam, don't come that tone. Now then, I must ask you to accompany me down to the dairy and do some aptitude tests.
Lady | I've got better things to do than come down to the dairy!
Milkman | Mrs Ratbag, if you don't mind me saying so, you are badly in need of an expensive course of psychiatric treatment. Now I'm not going to say a trip to our dairy will cure you, but it will give hundreds of lower-paid workers a good laugh.
Lady | All right... but how am I going to get home?
Milkman | I'll run you there and back on my psychiatrist's float.
Lady | All right.
| The milkman and lady walk down her garden path. As they go out of the garden gate there's a cat on the garden wall. CAPTION and arrow: 'A CAT' The cat explodes. The milkman motions her towards the milk float with a large signboard which reads: 'Psychiatrist's Dairy Ltd'. Just as they are getting in, she points to all the files in the back in milk crates.
Lady | What are those?
Milkman | They're case histories. (drives off; the van speaker announces: 'Psychiatrists! Psychiatrists!' The doctor from the Scots sketch hails him) Yes, sir?
Doctor | Ah, good morning. I'm afraid our regular psychiatrist hasn't come round this morning ... and I've got an ego block which is in turn making my wife over-assertive and getting us both into a state of depressive neurosis.
Milkman | Oh, I see, sir. Who's your regular, sir?
Doctor | Jersey Cream Psychiatrists.
Milkman | Oh yes, I know them. (puts down crate and gets out note pad) Right, well, er, what's your job, then?
Doctor | I'm a doctor.
Milkman | ... Didn't I see you just now under a Scotsman?
Doctor | Yes, but I am a doctor. Actually, I'm a gynaecologist but that was my lunchhour.
Milkman | (taking a card out of crate and showing it to the doctor) What does this remind you of?.
Doctor | Two pints of cream.
Milkman | Right... well I should definitely say you're suffering from a severe personality disorder, sir, sublimating itself in a lactic obsession which could get worse depending on how much money you've got.
Doctor | Yes, yes, I see. And a pot of yogurt, please.
| Cut to a psychiatrist called Dr Cream in his office.
Dr Cream | I would like to take this opportunity of complaining about the way in which these shows are continually portraying psychiatrists who make pat diagnoses of patients' problems without first obtaining their full medical history.
| Cut back to milkman with doctor.
Milkman | (handing over yogurt) Mind you, that's just a pat diagnosis made without first obtaining your full medical history.
| Cut to man at desk.
Man | I feel the time has come to complain about people who make rash complaints without first making sure that those complaints are justified.
| Cut to Dr Cream.
Dr Cream | Are you referring to me?
| Cut back to man.
Man | Not necessarily, however, I would like to point out that the BALPA spokesman was wearing the British Psychiatric Association Dinner Dance Club cuff-links.
| Cut to Dr Cream.
Dr Cream | Oh yes, I noticed that too.
| Cut to BALPA man.
BALPA Man | These are not British Psychiatric Association Dinner Dance Club cuff-links.
| Cut to man.
Man | Sorry.
| Cut to BALPA man.
BALPA Man | They are in fact British Sugar Corporation Gilbert-and-Sullivan Society cuff-links. It is in fact a sort of in-joke with us lads here at BALPA. I think the last speaker should have checked his facts before making his own rash complaint.
| Cut to Dr Cream.
Dr Cream | Yes, that'll teach him.
| Cut to BALPA man.
BALPA Man | However, I would just like to add a complaint about shows that have too many complaints in them as they get very tedious for the average viewer.
| Cut to another man.
Another Man | I'd like to complain about people who hold things up by complaining about people complaining. It's about time something was done about it. (the sixteen-ton weight falls on him)
| Cut to a street with milkman and lady riding on milk float. It comes to a halt. They get out, milkman hails a milkmaid with yoke and two pails.
Milkman | Nurse! Would you take Mrs Pim to see Dr Cream, please.
Milkmaid | Certainly, doctor. Walk this way, please.
Lady | Oh, if I could walk that way I...
Milkman and Milkmaid | Sssssh!
| The milkmaid leads Mrs Pim into a building, and into a psychiatrist's office. Dr Cream is in a chair.
Milkmaid | Mrs Pim to see you, Dr Cream.
Dr Cream | Ah yes. I just want another five minutes with Audrey. Could you show Mrs Pim into the waiting room, please.
Milkmaid | Yes, doctor.
| As milkmaid and Mrs Pim leave the room we see that there is a cow on the couch.
Dr Cream | Right, Audrey. When did you first start thinking you were a cow?
| Milkmaid and Mrs Pim emerge from building through a herd of cows and we then have a montage of shots of them walking through countryside as in opening sequence of flying lesson sketch at beginning of show. They pass a tea trolley woman, the bishop learning his script...
Bishop | (Australian accent) 'Jeez, Mr Belpit your legs is all swollen'...
| ...the secretary at her desk, past the stuffed animals which explodes, then past the tea lady again, and then past the bishop again and then past the secretary again, still going in the same direction.
Bishop | (Scots accent) 'Oi, Mr Belpit - your great legs is all swollen!'...(then again with japanese accent)
| Cut to montage of photographs of sections of brain, a man with an egg in his head, a man looking through microscope, diagrams of brain, music over this and: CAPTION: 'IT'S THE MIND - A WEEKLY MAGAZINE OF THINGS PSYCHIATRIC' Cut to a man sitting at usual desk. He is Mr Boniface.
Boniface | Good evening. Tonight on 'It's the Mind', we examine the phenomenon of déjà vu. That strange feeling we sometimes get that we've lived through something before, that what is happening now has already happened. Tonight on 'It's the Mind' we examine the phenomenon of déjà vu, that strange feeling we sometimes get that we've ... (looks puzzled for a moment) Anyway, tonight on 'It's the Mind' we examine the phenomenon of déjà vu, that strange...
| Cut to opening title sequence with montage of psychiatric photos and the two captions and music over. Cut back to Mr Boniface at desk, shaken. CAPTION: 'IT'S THE MIND'
Boniface | Good evening. Tonight on 'It's the Mind' we examine the phenomenon of déjà vu, that strange feeling we someti... mes get ... that ... we've lived through something...
| Cut to opening titles again. Back then to Boniface, now very shaken. CAPTION: 'IT'S THE MIND'
Boniface | Good ... good evening. Tonight on 'It's the Mind' we examine the phenomenon of dddddddddddéjà vvvvvvvvuu, that extraordinary feeling... quite extraordinary... (he tails off, goes quiet, the phone rings, he picks it up) No, fine thanks, fine. (he rings off, a man comes in on the right and hands him glass of water and leaves) Oh, thank you. That strange feeling we sometimes get that we've lived through something before. (phone rings again; he picks it up) No, fine thank you. Fine. (he rings off; a man comes in from right and hands him a glass of water; he jumps) ... Thank you. That strange feeling ... (phone rings; he answers) No. Fine, thank you. Fine. (ring off; a man enters and gives him glass of water) thank you. (he screams with fear) Look, something's happening to me. I - I - um, I think I'd better go and see someone. Goodnight.
| Phone rings again. He leaps from desk and runs out of shot. He runs out of building into street and chases after passing milk float and leaps aboard.
Milkman | Oi, haven't I seen you somewhere before?
Boniface | No, doctor, no. Something very funny's happening to me.
| CAPTION: 'IT'S THE MIND -- A WEEKLY MAGAZINE OF THINGS PSYCHIATRIC' Cut to montage of photographs again with captions and music. Cut to Boniface at desk. Boniface screams and runs out of shot. Cut to same piece of film as just previously, when he chases float, leaps on and the milkman says:
Milkman | Oi, haven't I seen you somewhere before?
Boniface | No, doctor, no. Something very funny's happening to me.
| The milk float goes past in the background with the milkman and Boniface on it. We see the float go along the country lane past the clearing, past the bishop...
Bishop | (camp) 'Oh, Mr Belpit, your legs are so swollen.'
| .. and the secretary at her desk, past a sign saying 'to the zoo' where explosions are heard, and stops outside Dr Cream's building... Boniface runs into building and enters Dr Cream's office.
Dr Cream | Ah, come in. Now what seems to be the matter?
Boniface | I have this terrible feeling of déjà vu.
| Repeat same clip from Boniface entering.
Dr Cream | Ah, come in. Now what seems to be the matter?
Boniface | I have this terrible feeling of déjà vu..
| Repeat clip again. SUPERIMPOSED CREDITS
Dr Cream | Ah, come in. Now what seems to be the matter?
Boniface | I have this terrible feeling of déjà vu..
| Clip starts to repeat again as the programme ends.